==> asr_business-0.1.9.4.tar.gz: asr_business-0.1.9.4/src/asr_business/asr.py <==
import os
import sys
import warnings

warnings.filterwarnings("ignore")

from funasr import AutoModel

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
sys.path.append(BASE_DIR)
import chinese2digits as c2d

digit_num = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9']


class Asr:
    def __init__(self,
                 asr_model_path,
                 punc_model_path,
                 batch_size=40,
                 device="cuda:0"):
        """
        asr_model_path: asr模型文件
        punc_model_path: 标点预测模型文件
        batch_size: 单次识别的数量，默认为40
        device: 模型推理的设备，默认为cuda:0
        """
        self.batch_size = batch_size
        self.asr_model = AutoModel(
            model=asr_model_path,
            device=device,
            disable_update=True
        )
        self.punc_model = AutoModel(
            model=punc_model_path,
            device=device,
            disable_update=True
        )

    @staticmethod
    def convert_chinese_to_digits(item):
        """
        将文本中的 中文数字 转化为 阿拉伯数字
        :param item:
        :return:
        """
        text = item['text']
        key = item['key']
        converted_text = c2d.takeNumberFromString(text)['replacedText']
        converted_text = list(converted_text)
        for i in range(len(converted_text)):
            if converted_text[i] == "1" and converted_text[i + 1] not in digit_num:
                converted_text[i] = "一"
        converted_text = "".join(converted_text)
        return {'key': key, 'text': converted_text}

    def add_punctuation(self, item):
        """
        为 文本添加标点
        :param item:
        :return:
        """
        text = item['text']
        key = item['key']
        if text:
            punc_text = self.punc_model.generate(input=text, disable_pbar=True)[0]['text']
        else:
            punc_text = ""
        return {"key": key, "text": punc_text}

    def generate(self, input_files=None):
        """
        model生成函数
        :param input_files:
        :return:
        """
        res = self.asr_model.generate(
            input=input_files,
            language="zh",
            use_itn=True,
            batch_size=len(input_files) if self.batch_size > len(input_files) else self.batch_size,
            disable_pbar=True
        )
        res = list(map(self.add_punctuation, res))
        res = list(map(self.convert_chinese_to_digits, res))
        return res

    def transcribe(self, audios):
        """
        将音频识别为文本
        :param audios: 音频文件，格式为列表
        :return:
        """
        res_ls = []
        valid_audios = []
        # 判断音频文件格式是否为.mp3，如果不是.mp3格式则删除文件
        for audio in audios:
            if audio.endswith('.mp3'):
                valid_audios.append(audio)
        if not audios:
            raise ValueError("audios list can't be empty")
        # 当batch size大于音频列表的长度时，将整个音频列表喂入模型
        if self.batch_size >= len(valid_audios):
            res = self.generate(valid_audios)
            res_ls.append(res)
        # 当batch size小于音频列表长度时，以batch size为step，将音频列表进行切割，分批次喂入模型
        else:
            batch = [valid_audios[i:i + self.batch_size] for i in range(0, len(valid_audios), self.batch_size)]
            for input_files in batch:
                res = self.generate(input_files)
                res_ls.append(res)
        return res_ls

==> asr_business-0.2.2.tar.gz: asr_business-0.2.2/src/asr_business/asr.py <==
import os
import sys
import warnings

warnings.filterwarnings("ignore")

from funasr import AutoModel

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
sys.path.append(BASE_DIR)
import chinese2digits as c2d

digit_num = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9']


class Asr:
    def __init__(self,
                 asr_model_path,
                 punc_model_path,
                 batch_size=40,
                 device="cuda:0"):
        """
        asr_model_path: asr模型文件
        punc_model_path: 标点预测模型文件
        batch_size: 单次识别的数量，默认为40
        device: 模型推理的设备，默认为cuda:0
        """
        self.batch_size = batch_size
        self.asr_model = AutoModel(
            model=asr_model_path,
            device=device,
            disable_update=True
        )
        self.punc_model = AutoModel(
            model=punc_model_path,
            device=device,
            disable_update=True
        )

    @staticmethod
    def convert_chinese_to_digits(item):
        """
        将文本中的 中文数字 转化为 阿拉伯数字
        :param item:
        :return:
        """
        text = item['text']
        key = item['key']
        converted_text = c2d.takeNumberFromString(text)['replacedText']
        converted_text = list(converted_text)
        for i in range(len(converted_text)):
            if converted_text[i] == "1" and converted_text[i + 1] not in digit_num:
                converted_text[i] = "一"
        converted_text = "".join(converted_text)
        return {'key': key, 'text': converted_text}

    def add_punctuation(self, item):
        """
        为 文本添加标点
        :param item:
        :return:
        """
        text = item['text']
        key = item['key']
        if text:
            punc_text = self.punc_model.generate(input=text, disable_pbar=True)[0]['text']
        else:
            punc_text = ""
        return {"key": key, "text": punc_text}

    def generate(self, input_files=None):
        """
        model生成函数
        :param input_files:
        :return:
        """
        res = self.asr_model.generate(
            input=input_files,
            language="zh",
            use_itn=True,
            batch_size=len(input_files) if self.batch_size > len(input_files) else self.batch_size,
            disable_pbar=True
        )
        res = list(map(self.add_punctuation, res))
        res = list(map(self.convert_chinese_to_digits, res))
        return res

    def transcribe(self, audios):
        """
        将音频识别为文本
        :param audios: 音频文件，格式为列表
        :return:
        """
        res_ls = []
        valid_audios = []
        # 判断音频文件格式是否为.mp3，如果不是.mp3格式则删除文件
        for audio in audios:
            if audio.endswith('.mp3'):
                valid_audios.append(audio)
        if not audios:
            raise ValueError("asr in progress, audios list can't be empty")
        # 当batch size大于音频列表的长度时，将整个音频列表喂入模型
        if self.batch_size >= len(valid_audios):
            res = self.generate(valid_audios)
            res_ls.append(res)
        # 当batch size小于音频列表长度时，以batch size为step，将音频列表进行切割，分批次喂入模型
        else:
            batch = [valid_audios[i:i + self.batch_size] for i in range(0, len(valid_audios), self.batch_size)]
            for input_files in batch:
                res = self.generate(input_files)
                res_ls.append(res)
        return res_ls
